==> request-tracker4_4.4.6+dfsg.orig-third-party-source.tar.gz: rt-4.4.6/devel/third-party/ckeditor-src/plugins/link/lang/mk.js <==
﻿/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'link', 'mk', {
	acccessKey: 'Access Key', // MISSING
	advanced: 'Advanced', // MISSING
	advisoryContentType: 'Advisory Content Type', // MISSING
	advisoryTitle: 'Advisory Title', // MISSING
	anchor: {
		toolbar: 'Anchor',
		menu: 'Edit Anchor',
		title: 'Anchor Properties',
		name: 'Anchor Name',
		errorName: 'Please type the anchor name',
		remove: 'Remove Anchor'
	},
	anchorId: 'By Element Id', // MISSING
	anchorName: 'By Anchor Name', // MISSING
	charset: 'Linked Resource Charset', // MISSING
	cssClasses: 'Stylesheet Classes', // MISSING
	emailAddress: 'E-Mail Address', // MISSING
	emailBody: 'Message Body', // MISSING
	emailSubject: 'Message Subject', // MISSING
	id: 'Id', // MISSING
	info: 'Link Info', // MISSING
	langCode: 'Language Code', // MISSING
	langDir: 'Language Direction', // MISSING
	langDirLTR: 'Left to Right (LTR)', // MISSING
	langDirRTL: 'Right to Left (RTL)', // MISSING
	menu: 'Edit Link', // MISSING
	name: 'Name',
	noAnchors: '(No anchors available in the document)', // MISSING
	noEmail: 'Please type the e-mail address', // MISSING
	noUrl: 'Please type the link URL', // MISSING
	other: '<other>', // MISSING
	popupDependent: 'Dependent (Netscape)', // MISSING
	popupFeatures: 'Popup Window Features', // MISSING
	popupFullScreen: 'Full Screen (IE)', // MISSING
	popupLeft: 'Left Position', // MISSING
	popupLocationBar: 'Location Bar', // MISSING
	popupMenuBar: 'Menu Bar', // MISSING
	popupResizable: 'Resizable', // MISSING
	popupScrollBars: 'Scroll Bars', // MISSING
	popupStatusBar: 'Status Bar', // MISSING
	popupToolbar: 'Toolbar', // MISSING
	popupTop: 'Top Position', // MISSING
	rel: 'Relationship', // MISSING
	selectAnchor: 'Select an Anchor', // MISSING
	styles: 'Style', // MISSING
	tabIndex: 'Tab Index', // MISSING
	target: 'Target', // MISSING
	targetFrame: '<frame>', // MISSING
	targetFrameName: 'Target Frame Name', // MISSING
	targetPopup: '<popup window>', // MISSING
	targetPopupName: 'Popup Window Name', // MISSING
	title: 'Link', // MISSING
	toAnchor: 'Link to anchor in the text', // MISSING
	toEmail: 'E-mail', // MISSING
	toUrl: 'URL', // MISSING
	toolbar: 'Link', // MISSING
	type: 'Link Type', // MISSING
	unlink: 'Unlink', // MISSING
	upload: 'Upload' // MISSING
} );

==> request-tracker5_5.0.3+dfsg.orig-third-party-source.tar.gz: rt-5.0.3/devel/third-party/ckeditor-src/plugins/link/lang/mk.js <==
﻿/*
Copyright (c) 2003-2019, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'link', 'mk', {
	acccessKey: 'Access Key', // MISSING
	advanced: 'Advanced', // MISSING
	advisoryContentType: 'Advisory Content Type', // MISSING
	advisoryTitle: 'Advisory Title', // MISSING
	anchor: {
		toolbar: 'Anchor',
		menu: 'Edit Anchor',
		title: 'Anchor Properties',
		name: 'Anchor Name',
		errorName: 'Please type the anchor name',
		remove: 'Remove Anchor'
	},
	anchorId: 'By Element Id', // MISSING
	anchorName: 'By Anchor Name', // MISSING
	charset: 'Linked Resource Charset', // MISSING
	cssClasses: 'Stylesheet Classes', // MISSING
	download: 'Force Download', // MISSING
	displayText: 'Display Text', // MISSING
	emailAddress: 'E-Mail Address', // MISSING
	emailBody: 'Message Body', // MISSING
	emailSubject: 'Message Subject', // MISSING
	id: 'Id',
	info: 'Link Info', // MISSING
	langCode: 'Код на јазик',
	langDir: 'Насока на јазик',
	langDirLTR: 'Лево кон десно',
	langDirRTL: 'Десно кон лево',
	menu: 'Edit Link', // MISSING
	name: 'Name',
	noAnchors: '(No anchors available in the document)', // MISSING
	noEmail: 'Please type the e-mail address', // MISSING
	noUrl: 'Please type the link URL', // MISSING
	noTel: 'Please type the phone number', // MISSING
	other: '<other>', // MISSING
	phoneNumber: 'Phone number', // MISSING
	popupDependent: 'Dependent (Netscape)', // MISSING
	popupFeatures: 'Popup Window Features', // MISSING
	popupFullScreen: 'Full Screen (IE)', // MISSING
	popupLeft: 'Left Position', // MISSING
	popupLocationBar: 'Location Bar', // MISSING
	popupMenuBar: 'Menu Bar', // MISSING
	popupResizable: 'Resizable', // MISSING
	popupScrollBars: 'Scroll Bars', // MISSING
	popupStatusBar: 'Status Bar', // MISSING
	popupToolbar: 'Toolbar', // MISSING
	popupTop: 'Top Position', // MISSING
	rel: 'Relationship', // MISSING
	selectAnchor: 'Select an Anchor', // MISSING
	styles: 'Стил',
	tabIndex: 'Tab Index', // MISSING
	target: 'Target', // MISSING
	targetFrame: '<frame>', // MISSING
	targetFrameName: 'Target Frame Name', // MISSING
	targetPopup: '<popup window>', // MISSING
	targetPopupName: 'Popup Window Name', // MISSING
	title: 'Врска',
	toAnchor: 'Link to anchor in the text', // MISSING
	toEmail: 'E-mail', // MISSING
	toUrl: 'URL',
	toPhone: 'Phone', // MISSING
	toolbar: 'Врска',
	type: 'Link Type', // MISSING
	unlink: 'Unlink', // MISSING
	upload: 'Прикачи'
} );
